@@ -4,7 +4,7 @@
 An python implementation triplet component filtering .
 Created on Thu Dec 30 12:37:56 2021
 @author: nwoye chinedu i.
-icube, unistra
+(c) camma, icube, unistra
 """
 #%%%%%%%% imports %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 import numpy as np
@@ -77,7 +77,8 @@ class Disentangle(object):
             return np.array(list(map(self.decompose, inputs, component)))
 
     def map_file(self):
-        return np.array([ [ 0,  0,  2,  1,  2,  1],
+        return np.array([ 
+                       [ 0,  0,  2,  1,  2,  1],
                        [ 1,  0,  2,  0,  2,  0],
                        [ 2,  0,  2, 10,  2, 10],
                        [ 3,  0,  0,  3,  0,  3],
@@ -176,4 +177,5 @@ class Disentangle(object):
                        [96,  2,  9, 14, 29, 44],
                        [97,  3,  9, 14, 39, 59],
                        [98,  4,  9, 14, 49, 74],
-                       [99,  5,  9, 14, 59, 89]])
\ No newline at end of file
+                       [99,  5,  9, 14, 59, 89]
+                       ])
\ No newline at end of file
