@@ -4,7 +4,7 @@
 An python implementation recognition AP for surgical action triplet evaluation.
 Created on Thu Dec 30 12:37:56 2021
 @author: nwoye chinedu i.
-icube, unistra
+(c) icube, unistra
 """
 #%%%%%%%% imports %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 import numpy as np
@@ -112,7 +112,7 @@ class Recognition(Disentangle):
         else:
             sys.exit(f"Function filtering {component} not yet supported!")
         with warnings.catch_warnings():
-            warnings.filterwarnings(action='ignore', message='Mean of empty slice')            
+            warnings.filterwarnings(action='ignore', message='[info] triplet classes not represented in this test sample will be reported as nan values.')            
             classwise = average_precision_score(targets, predicts, average=None)
             if (ignore_null and component=="ivt"): classwise = classwise[:-6]
             mean      = np.nanmean(classwise)
@@ -145,7 +145,7 @@ class Recognition(Disentangle):
         else:
             sys.exit(f"Function filtering {component} not yet supported!")            
         with warnings.catch_warnings():
-            warnings.filterwarnings(action='ignore', message='Mean of empty slice')            
+            warnings.filterwarnings(action='ignore', message='[info] triplet classes not represented in this test sample will be reported as nan values.')            
             classwise = average_precision_score(targets, predicts, average=None)
             if (ignore_null and component=="ivt"): classwise = classwise[:-6]
             mean      = np.nanmean(classwise)
@@ -172,7 +172,7 @@ class Recognition(Disentangle):
             global_predictions.append(self.predictions)
         video_log = []
         with warnings.catch_warnings():
-            warnings.filterwarnings(action='ignore', message='Mean of empty slice')
+            warnings.simplefilter("ignore", category=RuntimeWarning)
             for targets, predicts in zip(global_targets, global_predictions):
                 if component in ["ivt", "it", "iv", "t", "v", "i"]:
                     targets  = self.extract(targets, component)
@@ -181,10 +181,10 @@ class Recognition(Disentangle):
                     sys.exit(f"Function filtering {component} not yet supported!")                        
                 classwise = average_precision_score(targets, predicts, average=None)
                 video_log.append( classwise.reshape([1,-1]) )
-        video_log = np.concatenate(video_log, axis=0)         
-        videowise = np.nanmean(video_log, axis=0)
-        if (ignore_null and component=="ivt"): videowise = videowise[:-6]
-        mean      = np.nanmean(videowise)
+            video_log = np.concatenate(video_log, axis=0)         
+            videowise = np.nanmean(video_log, axis=0)
+            if (ignore_null and component=="ivt"): videowise = videowise[:-6]
+            mean      = np.nanmean(videowise)
         return {"AP":videowise, "mAP":mean}
 
     ##%%%%%%%%%%%%%%%%%%% TOP OP #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
